==> olo-0.2.1.tar.gz: olo-0.2.1/README.md <==
<p align="center">
    <img width="160" src="https://rawcdn.githack.com/yetone/figure_bed/master/olo_logo4.png" >
</p>

# 

<p align="center">
    <a href="https://scrutinizer-ci.com/g/yetone/olo/">
        <img alt="Build Status" src="https://scrutinizer-ci.com/g/yetone/olo/badges/build.png?b=master">
    </a>
    <a href="https://scrutinizer-ci.com/g/yetone/olo/">
        <img alt="Coverage Status" src="https://scrutinizer-ci.com/g/yetone/olo/badges/coverage.png?b=master" />
    </a>
    <a href="https://app.fossa.io/projects/git%2Bgithub.com%2Fyetone%2Folo?ref=badge_shield" alt="FOSSA Status"><img src="https://app.fossa.io/api/projects/git%2Bgithub.com%2Fyetone%2Folo.svg?type=shield"/></a>
    <a href="https://www.codacy.com/project/yetone/olo/dashboard?utm_source=github.com&utm_medium=referral&utm_content=yetone/olo&utm_campaign=Badge_Grade_Dashboard">
        <img alt="code quality" src="https://api.codacy.com/project/badge/Grade/a5ad69c098814cb18cfe28174cf7f35b?isInternal=true" />
    </a>
    <a href="https://scrutinizer-ci.com/g/yetone/olo/">
        <img alt="code quality" src="https://img.shields.io/scrutinizer/g/yetone/olo/master.svg" />
    </a>
    <br />
    <a href="https://pypi.org/project/olo">
        <img alt="PyPI Package latest release" src="https://img.shields.io/pypi/v/olo.svg" />
    </a>
    <a href="https://pypi.org/project/olo">
        <img alt="PyPI Wheel" src="https://img.shields.io/pypi/wheel/olo.svg" />
    </a>
    <a href="https://www.python.org">
        <img alt="Support Python Version" src="https://img.shields.io/badge/Python-2.7-brightgreen.svg">
    </a>
    <a href="https://www.python.org">
        <img alt="Support Python Version" src="https://img.shields.io/badge/Python-3.6-brightgreen.svg">
    </a>
</p>

<p align="center">
    ORM with intelligent and elegant cache manager.
</p>

<p align="center">
    <a href="https://yetone.github.io/olo/">查看文档 📖</a>
</p>

<h2 align="center">TL;DR</h2>
<p align="center">
    <img src="https://rawcdn.githack.com/yetone/figure_bed/master/olo1.svg" />
</p>

<h2 align="center">License</h2>
<p align="center">
    <a href="https://app.fossa.io/projects/git%2Bgithub.com%2Fyetone%2Folo?ref=badge_large">
        <img alt="FOSSA Status" src="https://app.fossa.io/api/projects/git%2Bgithub.com%2Fyetone%2Folo.svg?type=large" />
    </a>
</p>

==> olo-0.4.0.tar.gz: olo-0.4.0/README.md <==
<p align="center">
    <img width="160" src="https://rawcdn.githack.com/yetone/figure_bed/master/olo_logo4.png" >
</p>

# 

<p align="center">
    <a href="https://travis-ci.org/yetone/olo">
        <img alt="Build Status" src="https://travis-ci.org/yetone/olo.svg?branch=master">
    </a>
    <a href="https://codecov.io/gh/yetone/olo">
        <img alt="Coverage Status" src="https://codecov.io/gh/yetone/olo/branch/master/graph/badge.svg" />
    </a>
    <a href="https://app.fossa.io/projects/git%2Bgithub.com%2Fyetone%2Folo?ref=badge_shield" alt="FOSSA Status"><img src="https://app.fossa.io/api/projects/git%2Bgithub.com%2Fyetone%2Folo.svg?type=shield"/></a>
    <br />
    <a href="https://pypi.org/project/olo">
        <img alt="PyPI Package latest release" src="https://img.shields.io/pypi/v/olo.svg" />
    </a>
    <a href="https://pypi.org/project/olo">
        <img alt="PyPI Wheel" src="https://img.shields.io/pypi/wheel/olo.svg" />
    </a>
    <a href="https://www.python.org">
        <img alt="Support Python Version" src="https://img.shields.io/badge/Python-3.8-brightgreen.svg">
    </a>
</p>

<p align="center">
    ORM with intelligent and elegant cache manager.
</p>

<p align="center">
    <a href="https://yetone.github.io/olo/">查看文档 📖</a>
</p>

<h2 align="center">TL;DR</h2>
<p align="center">
    <img src="https://rawcdn.githack.com/yetone/figure_bed/master/olo1.svg" />
</p>

<h2 align="center">License</h2>
<p align="center">
    <a href="https://app.fossa.io/projects/git%2Bgithub.com%2Fyetone%2Folo?ref=badge_large">
        <img alt="FOSSA Status" src="https://app.fossa.io/api/projects/git%2Bgithub.com%2Fyetone%2Folo.svg?type=large" />
    </a>
</p>
